Skip to contents

Retrieves the formula used to create a ftmglm or ftmlm model

Usage

# S4 method for class 'ftmglm'
formula(x)

# S4 method for class 'ftmlm'
formula(x)

Arguments

x

Object of class inheriting from ftmglm or ftmlm.

Value

an object of class 'formula'

Note

If the ftmglm or ftmlm object was created from a cv.glmnet object, the outcome variable will be named "y", rather than the original name.