Skip to contents

Generic function to extract R-squared values from various model types in the FTM package.

Usage

rsq(object, ...)

Arguments

object

A model object from which to extract the R-squared value

...

Additional arguments passed to methods

Value

A numeric value representing the R-squared or pseudo-R-squared value