Skip to contents

Allows the subsetting of ftmglm or ftmlm objects in order to restrict the model to use only the specified variables.

Usage

# S4 method for class 'ftmglm'
subset(x, subset)

# S4 method for class 'ftmlm'
subset(x, subset)

Arguments

x

Object of class inheriting from ftmglm or ftmlm.

subset

A character string of variables or indices to use.

Value

A ftmglm or ftmlm object that only uses the specified variables.