formula-ftmglm-method.Rd
Retrieves the formula used to create a ftmglm or ftmlm model
ftmglm
ftmlm
# S4 method for class 'ftmglm' formula(x) # S4 method for class 'ftmlm' formula(x)
Object of class inheriting from ftmglm or ftmlm.
an object of class 'formula'
If the ftmglm or ftmlm object was created from a cv.glmnet object, the outcome variable will be named "y", rather than the original name.
cv.glmnet