Flexible Transfer Model (FTM) Generalized Linear Model Class
ftmglm-class.RdAn S4 class designed to encapsulate the necessary components for a flexible transfer model generalized linear model. This class stores matrices that represent the weighted cross-product of predictors and the cross-product of predictors with outcomes, essential for the model calculations.