subset-ftmglm-method.Rd
Allows the subsetting of ftmglm or ftmlm objects in order to restrict the model to use only the specified variables.
ftmglm
ftmlm
# S4 method for class 'ftmglm' subset(x, subset) # S4 method for class 'ftmlm' subset(x, subset)
Object of class inheriting from ftmglm or ftmlm.
A character string of variables or indices to use.
A ftmglm or ftmlm object that only uses the specified variables.